function [C,P]=bvalue(U,K,T,r,v)
%BVALUE The Black (1976) Model for evaluating European options on futures
%	contracts, where the option is subject to stock type settlement.
%	If options are subject to futures type settlement, set r=0.
%
%	Syntax: [C,P] = BVALUE(U,K,T,r,v)
%
%	U	- the price of the underlying futures contract
%	K	- the strike price
%	T	- the time to expiration in days
%	r	- the risk free interest rate in percent
%	v	- the annual volatility in percent
%
%	C	- the theoretical value of a call
%	P	- the theoretical value of a put

% Copyright (c) 1996-98 by Rafal Weron.
% Written by: R. Weron.

T=T/365;
e_rt=exp(-0.01*r.*T);
vt=0.01*v.*sqrt(T);
h=(log(U./K)./vt)+vt/2;

C=U.*e_rt.*normcdf(h)-K.*e_rt.*normcdf(h-vt);
P=-U.*e_rt.*normcdf(-h)+K.*e_rt.*normcdf(vt-h);
