function findemo(action)
%FINDEMO Financial Engineering Toolbox v. 2.5 Demo.
%
%	Syntax: FINDEMO

% Copyright (c) 1996-2001 by Rafal Weron.
% Written by: R. Weron.

global FIGURE COLOR;

warning off

if nargin==0
  action='init';
end

if strcmp(action,'init')
  COLOR=[.7 .8 .9];
  labels=['Profit and loss (P/L) graphs      ';...
          'Greeks (Sensitivity analysis)     ';...
          'General discrete model            ';...
          'Convergence of the discrete model ';...
          'Exotic options (binary tree)      ';...
          'Exotic options (recursive tree)   ';...
          'Exotic options (Monte Carlo)      ';...
          'About...                          ';...
          'Exit                              '];
  callbacks=['part1           ';...
             'part2           ';...
             'part3           ';...
             'part3c          ';...
             'part4           ';...
             'part5           ';...
             'part6           ';...
             'findemo(''about'')';...
             'findemo(''exit'') '];
  rows=size(labels,1);
  FIGURE=switch2(zeros(1,6),5);
  pos=get(FIGURE(5),'position');
  set(FIGURE(5),'resize','off',...
                'position',[pos(1)+130 pos(2)-20 320 (rows-1)*34+73],...
                'color',COLOR,...
                'menubar','none',...
                'numbertitle','off',...
                'name','Financial Engineering Toolbox v. 2.5');
  for i=1:rows,
    uicontrol('style','pushbutton',...
              'position',[30 (rows-i)*34+25 260 23],...
              'string',deblank(labels(i,:)),...
              'callback',deblank(callbacks(i,:)));
  end

elseif strcmp(action,'about')
  set(FIGURE(5),'visible','off');
  screen=get(0,'screensize');
  FIGURE=switch2(FIGURE,6);
  set(FIGURE(6),'resize','off',...
                'position',[(screen(3)-440)/2 (screen(4)-420)/2 440 420],...
                'color',COLOR,...
                'menubar','none',...
                'numbertitle','off',...
                'name','About...');
  drawnow;
  h=axes('position',[20/440 56/420 360/390 308/420]);
  set(h,'visible','off');

  h=text2(25,385,'Financial Engineering Toolbox v. 2.5');
  set(h,'fontsize',15,'color',[0 0 0]);
  h=text2(25,320,'To accompany book by A. Weron and R. Weron:');
  set(h,'fontsize',12,'color',[0 0 0]);
  h=text2(35,300,'Financial Engineering:');
  set(h,'fontsize',12,'color',[0 0 0],'fontangle','italic');
  h=text2(50,280,'Derivatives Pricing, Computer Simulations,');
  set(h,'fontsize',12,'color',[0 0 0],'fontangle','italic');
  h=text2(50,260,'Market Statistics');
  set(h,'fontsize',12,'color',[0 0 0],'fontangle','italic');
  h=text2(35,240,'WNT, Warsaw, 1998');
  set(h,'fontsize',12,'color',[0 0 0]);

  h=text2(25,180,'Dodatek do ksiazki A. Werona i R. Werona:');
  set(h,'fontsize',12,'color',[0 0 0]);
  h=text2(35,160,'Inzynieria finansowa:');
  set(h,'fontsize',12,'color',[0 0 0],'fontangle','italic');
  h=text2(50,140,'Wycena instrumentow pochodnych,');
  set(h,'fontsize',12,'color',[0 0 0],'fontangle','italic');
  h=text2(50,120,'Symulacje komputerowe, Statystyka rynku');
  set(h,'fontsize',12,'color',[0 0 0],'fontangle','italic');
  h=text2(35,100,'WNT, Warszawa, 1998');
  set(h,'fontsize',12,'color',[0 0 0]);

  h=text2(25,30,'Copyright (c) 1996-2001 by Rafal Weron');
  set(h,'fontsize',10,'color',[0 0 0]);

  uicontrol('style','pushbutton',...
            'position',[340 20 70 30],...
            'string','OK',...
            'callback','findemo(''ok'')');

elseif strcmp(action,'ok')
  close(FIGURE(6));
  set(FIGURE(5),'visible','on');

elseif strcmp(action,'exit')
  close(FIGURE(5));
  clear global FIGURE COLOR;
end
