function part3c(action)
%PART3C Internally used by FINDEMO.

% Copyright (c) 1996-2001 by Rafal Weron.
% Written by: R. Weron.

global FIGURE COLOR NUMBER MODE S0 T R V N1 N2 K K_TEXT ...
   PAYOUT PAYOUT_TEXT CP CALLPUT CALLPUT_TEXT TREE REBUILD;

if nargin==0
  action='init';
end
 
if strcmp(action,'init')   
  set(FIGURE(5),'visible','off');      % hides the main menu 

  FIGURE=switch2(FIGURE,1);
  pos=get(FIGURE(1),'position');
  set(FIGURE(1),'resize','off',...     
                'position',[pos(1) pos(2) 440 290],...
                'color',COLOR,...
                'menubar','none',...
                'numbertitle','off',...
                'name','Convergence of the discrete model');
  clf;

  uicontrol('style','text',...
            'position',[40 190 130 20],...
            'string','MODE'); 
  for i=1:2                             
    MODE(i)=uicontrol('style','radiobutton',... 
                      'position',[50 170-20*i 110 20],...
                      'callback',['part3c(''mode'')']);
  end
  set(MODE(1),'string','Plain vanilla','value',1); NUMBER=1; 
  set(MODE(2),'string','Generic','value',0);   
    
  uicontrol('style','text',...
            'position',[190 190 210 20],...
            'string','PARAMETERS');
  uicontrol('style','text',...
            'position',[200 150 30 20],...
            'string','So=');
  S0=uicontrol('style','edit',...
               'position',[240 150 50 20],...
               'string','100',...
               'callback','part3c(''rebuild'')');
  uicontrol('style','text',...
                    'position',[200 130 30 20],...
                    'string','n1=');
  N1=uicontrol('style','edit',...
              'position',[240 130 50 20],...
              'string','2',...
              'callback','part3c(''rebuild'')');
  uicontrol('style','text',...
                    'position',[200 110 30 20],...
                    'string','n2=');
  N2=uicontrol('style','edit',...
              'position',[240 110 50 20],...
              'string','20',...
              'callback','part3c(''rebuild'')');
            
  uicontrol('style','text',...
            'position',[300 150 30 20],...
            'string','T=');
  T=uicontrol('style','edit',...
              'position',[340 150 50 20],...
              'string','365');
  uicontrol('style','text',...
            'position',[300 130 30 20],...
            'string','r=');
  R=uicontrol('style','edit',...
              'position',[340 130 50 20],...
              'string','10');
  uicontrol('style','text',...
                    'position',[300 110 30 20],...
                    'string','v=');
  V=uicontrol('style','edit',...
              'position',[340 110 50 20],...
              'string','10',...
              'callback','part3c(''rebuild'')');

  K_TEXT=uicontrol('style','text',...
            'position',[300 90 30 20],...
            'string','K=');
  K=uicontrol('style','edit',...
              'position',[340 90 50 20],...
              'string','100');
           
  PAYOUT_TEXT=uicontrol('style','text',...
     'position',[40 70 360 20],...
     'visible','off',...
     'string','PAYOUT FORMULA');
  PAYOUT=uicontrol('style','edit',...		  
     'position',[50 30 340 20],...  
     'visible','off',...
     'string','max(S-100,0)');	  
                
  CALLPUT_TEXT=uicontrol('style','text',...
            'position',[40 70 130 20],...
            'string','OPTION TYPE');
  for i=1:2                             
    CALLPUT(i)=uicontrol('style','radiobutton',... 
                      'position',[50+55*(i-1) 30 55 20],...
                      'callback',['part3c(''callput'')']);
  end
  set(CALLPUT(1),'string','Call','value',1); CP=1; % 'call' is active  
  set(CALLPUT(2),'string','Put','value',0);   

  uicontrol('style','pushbutton',...
                   'position',[40 240 70 20],...  
                   'string','RUN',...		  
                   'callback','part3c(''start'')');
  uicontrol('style','pushbutton',...
            'position',[130 240 70 20],...
            'string','HELP',...
            'callback','part3c(''help'')');
  uicontrol('style','pushbutton',...
            'position',[220 240 70 20],...
            'string','EXIT',...
            'callback','part3c(''exit'')');

elseif strcmp(action,'rebuild')
   n1=str2num(get(N1,'string'));   
   n2=str2num(get(N2,'string'));   
   if n1<1, set(N1,'string','1'); end 
   if n2<=n1, set(N2,'string',int2str(n1+10)); end 
   REBUILD=1;

elseif strcmp(action,'mode')         % change window layout 
    list=get(0,'children');
    for i=1:length(list),
      if list(i)==FIGURE(2) | list(i)==FIGURE(3)
        close(list(i));
      end
    end
    if NUMBER==1
      set(MODE(1),'value',0);
      set(MODE(2),'value',1);
      set([PAYOUT PAYOUT_TEXT],'visible','on');
      set([CALLPUT CALLPUT_TEXT K K_TEXT],'visible','off');
      NUMBER=2;
    else
      set(MODE(1),'value',1);
      set(MODE(2),'value',0);
      set([PAYOUT PAYOUT_TEXT],'visible','off');
      set([CALLPUT CALLPUT_TEXT K K_TEXT],'visible','on');
      NUMBER=1;
    end			        
  
elseif strcmp(action,'callput')         % change option type
    if CP==1
      set(CALLPUT(1),'value',0);
      set(CALLPUT(2),'value',1);
      CP=2;
    else
      set(CALLPUT(1),'value',1);
      set(CALLPUT(2),'value',0);
      CP=1;
    end

elseif strcmp(action,'start')
  s0=str2num(get(S0,'string'));
  t=str2num(get(T,'string'));
  r=str2num(get(R,'string'));
  v=str2num(get(V,'string'));	   
  n1=str2num(get(N1,'string'));  
  n2=str2num(get(N2,'string'));  


  if NUMBER==1   % 'Compare with Black-Scholes'
     k=str2num(get(K,'string'));
     if CP==1, % call
        evalstr='c(l+first)=max(S-k,0);';
     else      % put
        evalstr='c(l+first)=max(k-S,0);';
     end
  else		     % 'Convergence'
     evalstr=['c(l+first)=' get(PAYOUT,'string') ';'];
     % AMERICAN
     % evala=['a=' get(PAYOUT,'string') ';'];            
  end
  
    count=1;
    for n=n1:n2          % calculate option premiums for n1<=n<=n2
      deltat = t/365/n;
      % WW-161
      % u=exp(0.01*v*sqrt(deltat));   
      % Wilmott-164
      u0 = (exp(-0.01*r*deltat) + exp((0.01*r + (0.01*v)^2)*deltat))/2;
      u = u0 + sqrt(u0^2 - 1);
      d = 1/u;
      s(1)=s0;  
      for i=1:n,
        first=(1+i)*i/2+1;
        for l=first:(first+i-1),
          s(l)=u*s(l-i);                
        end
        s(first+i)=d*s(first-1);        
      end; 
      first=(1+(n+1))*(n+1)/2-n;
      for l=0:n,
        S=s0*u^(n-2*l);
        eval(evalstr);
      end
      rr=exp(r*0.01*t/365/n);   % e^(r*qt)
      p=(rr-d)/(u-d);
      l1=p/rr;
      l2=(1-p)/rr;
      for i=n:-1:1,
        first=(1+i)*i/2-i+1;
        for l=first:(first+i-1),
          c(l)=l1*c(l+i)+l2*c(l+i+1);    
          S=s(l);
          % AMERICAN
          % eval(evala);          
          % c(l)=max(c(l),a); 
        end
      end
      data(count)=c(1);
      count=count+1;
    end
    
    FIGURE=switch2(FIGURE,2);
    set(FIGURE(2),'numbertitle','off',...
       'name','Convergence');
  
  if NUMBER==1   % 'Compare with Black-Scholes'
    [c,p]=bsvalue(s0,k,t,r,v);
    if CP==1, 
       plot(n1:n2,data,'b-o',[n1 n2],[c c],'r-');
       ylabel('Call option premium');
    else      
       plot(n1:n2,data,'b-o',[n1 n2],[p p],'r-');
       ylabel('Put option premium');
    end
    xlabel('Number of price jumps');
    legend('Discrete model','BS model')
    
    % Errors !!!!!!!
    %FIGURE=switch2(FIGURE,3);
    %set(FIGURE(3),'numbertitle','off',...
    %   'name','Errors');
    %if CP==1, 
    %   cc = zeros(size(data)) + c;
    %   bar(n1:n2,100*(data-cc)./cc);
    %else      
    %   pp = zeros(size(data)) + p;
    %   bar(n1:n2,100*(data-pp)./pp);
    %end
    %xlabel('Number of price jumps');
    %ylabel('Errors (in %)');
  else
    plot(n1:n2,data,'-o');
    xlabel('Number of price jumps');
    ylabel('Option premium');
  end

elseif strcmp(action,'help')
  page1=...
    ['RUN                                                   '
     '  plot the discrete model European option prices;     '
     '  for a plain vanilla option the Black-Scholes        '
     '  prices are plotted for comparison;                  '
     'HELP                                                  '
     '  this help window;                                   '
     'EXIT                                                  '
     '  return to FINDEMO;                                  '
     'MODE                                                  '
     '  select plain vanilla or generic option; for the     '
     '  generic option the payout formula must be given;    '
     'OPTION TYPE                                           '
     '  select Call or Put plain vanilla option;            '
     'PARAMETERS                                            '
     '  So - underlying instrument price at time 0;         '
     '  n1, n2 - minimum and maximum number of price jumps  ' 
     '  T - time to option maturity (in days);              '
     '  r - annual interest rate (in percent);              '
     '  v - annual volatility (in percent);                 '
     '  K - strike price of plain vanilla options;          '
     'PAYOUT FORMULA                                        '
     '  user defined function (dependend on S - underlying  '
     '  price at maturity), e.g. for the standard           '
     '  european call with strike 100: max(S-100,0);        '];

  page2=...
    ['RUN                                                   '
     '  wykres cen opcji europejskich w modelu dyskretnym;  '
     '  dla opcji waniliowych dodatkowo rysowana jest       '
     '  cena Blacka-Scholesa;                               '
     'HELP                                                  '
     '  pomoc;                                              '
     'EXIT                                                  '
     '  powrot do FINDEMO;                                  '
     'MODE                                                  '
     '  kategoria opcji: waniliowa lub ogolna;              '
     'OPTION TYPE                                           '
     '  rodzaj opcji: kupna lub sprzedazy;                  '
     'PARAMETERS                                            '
     '  So - cena instrumentu podstawowego w chwili 0;      '
     '  n1, n2 - minimalna i maksymalna liczba skokow ceny  ' 
     '  T - termin wygasniecia opcji (w dniach);            '
     '  r - roczna stopa procentowa (w procentach);         '
     '  v - roczna zmiennosc (w procentach);                '
     '  K - cena wykonania opcji waniliowych;               '
     'PAYOUT FORMULA                                        '
     '  funkcja wyplaty podawana przez uzytkownika,         '
     '  np. dla standardowej europejskiej opcji kupna       '
     '  z cena wykonania 100 wynosi: max(S-100,0);          '];

  buttonStr=['English';
             'Polski ';
             '       '];
  helpfn('Convergence of the discrete model',buttonStr,page1,page2);
  pos=get(gcf,'position');
  set(gcf,'name','Help',...
    'position',[pos(1) pos(2) 450 400],...
    'resize','off',...
    'menubar','none');

elseif strcmp(action,'exit')		
  list=get(0,'children');                
  for i=1:length(list),
    if list(i)~=FIGURE(5)
      close(list(i));
    end
  end
  set(FIGURE(5),'visible','on');
  clear global NUMBER MODE S0 T R V N1 N2 K K_TEXT ...
   PAYOUT PAYOUT_TEXT CP CALLPUT CALLPUT_TEXT TREE REBUILD;

end
