function position(p,minp,maxp,typepos)
%POSITION Plot a position consisting of underlying assets and options.
%
%	Syntax: POSITION(p{,minp,maxp,typepos})
%
%	p	- the 5 column position matrix:
%		  #contracts,
%		  1 (short) / -1 (long),
%		  strike,
%		  contract type: -1 (Put) / 0 (Underlying) / 1 (Call),
%		  premium
%	minp	- the minimum value of the price on the plot
%	maxp	- the maximum value of the price on the plot
%	typepos	- a nonzero value triggers printing the position

% Copyright (c) 1996-98 by Rafal Weron.
% Written by: K. Rojek, R. Seredynski, R. Weron.

if nargin<=3, typepos=0; end;

p=p';
nocontracts=p(1,:);
shortlong=p(2,:);
strike=p(3,:);
contract=p(4,:);
premium=p(5,:);
strikesorted=sort(strike);

% no price limits given
if nargin<=1,
  minstrike=min(strike);
  maxstrike=max(strike);
  difstrike=maxstrike-minstrike;
  if difstrike==0, difstrike=round(1+maxstrike/100); end;
  minp=minstrike-difstrike;
  maxp=maxstrike+difstrike;
end;

if typepos,
  nocontractsstr=sprintf('%8d',p(1,:));
  for i=1:length(shortlong)
    if shortlong(i)==1  shortlongstr(i)='S'; end;
    if shortlong(i)==-1 shortlongstr(i)='L'; end;
    if contract(i)==1   contractstr(i)='C'; end;
    if contract(i)==-1  contractstr(i)='P';end;
    if contract(i)==0   contractstr(i)='U';end;
    if contract(i)==0   premiumstr=[premiumstr sprintf('        ')];
    else premiumstr=[premiumstr sprintf('%8.2f',premium(i))];end;
  end;
  shortlongstr=sprintf('       %c',shortlongstr);
  strikestr=sprintf('%8d',strike);
  contractstr=sprintf('       %c',contractstr);
  disp(' ')
  disp('#contracts short/long  strike contract  premium')
  for i=1:length(strike),
    disp([nocontractsstr((i-1)*8+1:i*8),...
          shortlongstr((i-1)*8+1:i*8),'    ',...
          strikestr((i-1)*8+1:i*8),...
          contractstr((i-1)*8+1:i*8),'  ',...
          premiumstr((i-1)*8+1:i*8)]);
  end;
  disp(' ')
end;

x=[minp,strikesorted,maxp];
for i=1:length(x),
  y(i)=posvalue(x(i),nocontracts,shortlong,strike,contract,premium);
end

hold on;
grid on;
cla;

%ticks=y(1);
%for i=2:length(y),
%  if ~ismember(y(i),ticks), ticks=[ticks y(i)]; end;   
%end;  
ticks = sort(y);
ticks_compare = [ticks(1)+1, ticks];
ticks_compare(length(ticks_compare))=[];
indices = find ((ticks_compare == ticks) == 0);
ticks = ticks(indices);
  
if max(y)==min(y),
  if ~ismember(1,ticks), ticks=[ticks 1]; end;
  if ~ismember(0,ticks), ticks=[ticks 0]; end;
  if ~ismember(-1,ticks), ticks=[ticks -1]; end;
  ticks=sort(ticks);
else
  if ~ismember(0,ticks), ticks=[ticks 0]; end;
  ticks=sort(ticks);
end;

xx=x(1);
for i=2:length(x),
  if ~ismember(x(i),xx), xx=[xx x(i)]; end;   
end;  

set(gca,'PlotBoxAspectRatio',[1,1,1],'XTick',sort(xx),'YTick',ticks);
set(gca,'DataAspectRatio',[1,1,1]);
xlabel('Underlying');
ylabel('Loss / Profit');

% plot zero line
x2=[minp,maxp];
y2=[0,0];
plot(x2,y2,'r')

% plot position
plot(x,y)
hold off;
